==> pyzo_4.1.orig.tar.gz: pyzo-4.1/README.md <==
# Pyzo - The Interactive editor for scientific Python

Main website: [pyzo.org](http://pyzo.org)


### Description

Pyzo is a cross-platform Python IDE focused on
interactivity and introspection, which makes it very suitable for
scientific computing. Its practical design is aimed at simplicity and
efficiency.

It consists of two main components, the editor and the shell, and uses
a set of pluggable tools to help the programmer in various ways. Some
example tools are source structure, project manager, interactive help,
workspace ...

Pyzo is written in (pure) Python 3 and uses the Qt GUI toolkit. Binaries
are provided for all major operating system. After installing Pyzo, it
can be used to execute code on any Python version available on your
system (Python 2.4 - 3.x, including Pypy).


### Installation

Pyzo runs on Python3 and needs pyzolib and Pyside or PyQt4. On a modern
OS these should be easy to obtain. One can then install Pyzo with
`sudo python3 -m pip install pyzo`

We also provide binaries for Windows, Linux and OS X.


### License

Pyzo is free and open source. BSD licensed.


### About us

The development of Pyzo is coordinated by Almar Klein. See contributors.txt
for a complete list of people who helped develop Pyzo.


### Contributions

If you want to help out, create a pull request or start a discusiion
in our mailing list.


### More information

* main website: http://pyzo.org
* mailing list: http://groups.google.com/group/pyzo
* code repository: http://github.com/pyzo/pyzo
* wiki: http://github.com/pyzo/pyzo/wiki

==> pyzo_4.4.3.orig.tar.gz: pyzo-4.4.3/README.md <==
# Pyzo - The Interactive editor for scientific Python

Main website: [pyzo.org](http://pyzo.org)


### Description

Pyzo is a cross-platform Python IDE focused on
interactivity and introspection, which makes it very suitable for
scientific computing. Its practical design is aimed at simplicity and
efficiency.

It consists of two main components, the editor and the shell, and uses
a set of pluggable tools to help the programmer in various ways. Some
example tools are source structure, project manager, interactive help,
workspace ...

Pyzo is written in (pure) Python 3 and uses the Qt GUI toolkit. Binaries
are provided for all major operating system. After installing Pyzo, it
can be used to execute code on any Python version available on your
system (Python 2.4 - 3.x, including Pypy).


### Installation

Pyzo runs on Python3 and needs Pyside or PyQt4. On a modern
OS these should be easy to obtain. One can then install Pyzo with
`sudo python3 -m pip install pyzo`

We also provide binaries for Windows, Linux and OS X.


### License

Pyzo is free and open source. BSD licensed.


### About us

The development of Pyzo is coordinated by Almar Klein. See contributors.txt
for a complete list of people who helped develop Pyzo.


### Contributions

If you want to help out, create a pull request or start a discussion
in our mailing list.


### More information

* main website: http://pyzo.org
* mailing list: http://groups.google.com/group/pyzo
* code repository: http://github.com/pyzo/pyzo
* wiki: http://github.com/pyzo/pyzo/wiki
